//*****************************************************************************
//! msp_wm430fr4_golbal.h
//
//! Function Declarations.
//
//! \author Texas Instruments
//! \author A0222632
//
//! \version Release 1
//
//*****************************************************************************

#ifndef MSP_WM430FR4_GOLBAL_H_
#define MSP_WM430FR4_GOLBAL_H_

#include <msp430.h>
#include <stdint.h>
#include <stdbool.h>
#include <msp_ts430fr4_rs485.h>
#include <msp_ts430fr4_lcd.h>
#include <msp_ts430fr4_menu.h>
#include <msp_ts430fr4_measure.h>

#define Chinese_Version

#define Firmware_Version 0x01;              // Meter_ID
#define Meter_Num 0x01;

#define FRAM_RECORD_ADDRESS 0xFF00	 // Refresh every 1 second
#define FRAM_RECORD_CHECK 0xFF40	 // First record check address
#define FRAM_RECORD_BASE 0xFA00	     // Monthly record in stand-alone address


//*****************************************************************************
//
//! \typedef tWeekday
//!
//! Specifies the different
//! namely Standby or Active.
//!
//
//*****************************************************************************
typedef enum
{
	eSunday = 0x00,
	eMonday = 0x01,
	eTuesday = 0x02,
	eWednesday = 0x03,
	eThursday = 0x04,
	eFriday = 0x05,
	eSaturday = 0x06
}tWeekday;

// LED
#define LED_PORT_OUT	P8OUT
#define LED_PORT_DIR	P8DIR
#define RLED_BIT		BIT2
#define	GLED_BIT		BIT1
#define RLED_ON()		(LED_PORT_OUT |= RLED_BIT)
#define RLED_OFF()		(LED_PORT_OUT &=~ RLED_BIT)
#define RLED_TOGGLE()   (LED_PORT_OUT ^= RLED_BIT)
#define GLED_ON()		(LED_PORT_OUT |= GLED_BIT)
#define GLED_OFF()		(LED_PORT_OUT &=~ GLED_BIT)
#define GLED_TOGGLE()   (LED_PORT_OUT ^= GLED_BIT)

#define PWLED_PORT_OUT	P5OUT
#define PWLED_PORT_DIR	P5DIR
#define PWLED_BIT		BIT5
#define PWLED_ON()		(PWLED_PORT_OUT |= PWLED_BIT)
#define PWLED_OFF()		(PWLED_PORT_OUT &=~ PWLED_BIT)
#define PWLED_TOGGLE()  (PWLED_PORT_OUT ^= PWLED_BIT)

// KEY
#define KEY_PORT_OUT	P1OUT
#define KEY_PORT_IN		P1IN
#define	KEY_PORT_DIR	P1DIR
#define	KEY_PORT_SEL	P1SEL0
#define	KEY_PORT_REN	P1REN
#define	KEY_PORT_IFG	P1IFG
#define	KEY_PORT_IES	P1IES
#define	KEY_PORT_IE		P1IE
#define	KEY_MODE_BIT	BIT7
#define	KEY_POWER_BIT	BIT6
#define	KEY_UP_BIT		BIT5
#define	KEY_DOWN_BIT	BIT3

//RS485 Command
//#define
//#define
//#define
//#define
//#define
//#define
//#define
//#define
//#define
//#define

//SPI
#define	SPI_PORT_OUT	P5OUT
#define	SPI_PORT_IN		P5IN
#define SPI_PORT_DIR	P5DIR
#define	SPI_PORT_SEL	P5SEL0
#define	SPI_BIT_SCK		BIT1
#define	SPI_BIT_SIMO	BIT2
#define	SPI_BIT_SOMI	BIT3
#define	SPI_BIT_CS		BIT4

//RTC
typedef struct
{
	uint8_t YEAR;
	uint8_t MONTH;
	uint8_t DAY;
	uint8_t HOUR;
	uint8_t MINUTE;
	uint8_t SECOND;
	tWeekday Weekday;
}tRTCformat;

typedef struct
{
	int8_t HOUR;
	int8_t MINUTE;
	int8_t SECOND;
}tTimerformat;

extern tRTCformat tRTCData;
extern tTimerformat TimerData;

extern void TS_Initialize(void);
extern void ADC_OFF();
extern void ADC_ON();

extern void LCD_Display_Time(tRTCformat tData, tTimeformat tMode);
extern void LCD_Display_Timer(tTimerformat tData);
extern void LCD_Display_Temperature(uint16_t temp, tTempformat tMode);
extern void LCD_Display_BatteryVol(tBatteryvol tBattery);
extern void LCD_Display_Signal(bool OnOff);
extern void LCD_Display_TempSet(uint8_t temp, tTempformat tMode);
extern void LCD_Display_Fan(tFanLevel tFan);
extern void LCD_Display_TSMode(tTSMode tMode);
extern void LCD_Display_SettingMode(tSettingMode tMode);
extern void LCD_Display_Swing(tSwingStatus SStatus);

#endif /* MSP_WM430FR4_GOLBAL_H_ */
