//*****************************************************************************
//! msp_ts430fr4_menu.c
//
//! \author Texas Instruments
//! \author A0222632
//
//! \version Release 1
//
//*****************************************************************************

#include <msp_ts430fr4_golbal.h>

#pragma vector=PORT1_VECTOR
__interrupt void PORT1_ISR(void)
{
	uint16_t i;
	uint8_t PushKey;

	PushKey = KEY_PORT_IFG & (KEY_POWER_BIT + KEY_MODE_BIT + KEY_UP_BIT + KEY_DOWN_BIT);
	for(i=3000;i>0;i--)
	{
		_NOP();
	}
	if((KEY_PORT_IN&PushKey)==PushKey)
	{
		KEY_PORT_IFG = 0;
		return;
	}

	if(PushKey & KEY_POWER_BIT)
	{
		switch(SystemStatus)
		{
		case eActive:
			SystemStatus = eStandby;
			PWLED_OFF();
			LCD_Display_OFF();
			ADC_OFF();
			GLED_OFF();
			RLED_OFF();
			break;
		case eStandby:
			SystemStatus = eActive;
			SettingMode = eAll;
			Power_led_counter = 3;
			TimerData.HOUR = 1;
			TimerData.MINUTE = 0;
			TimerData.SECOND = 0;
			PWLED_ON();
			LCD_Display_ON();
			LCD_Display_LOGO();
			LCD_Display_Time(tRTCData,Timeformat);
			LCD_Display_Temperature(Temperature,Tempformat);
			LCD_Display_BatteryVol(BatteryVol);
			LCD_Display_TempSet(SettingTemp,Tempformat);
			LCD_Display_Fan(FanLevel);
			LCD_Display_TSMode(TSMode);
			LCD_Display_SettingMode(SettingMode);
			break;
		}
		KEY_PORT_IFG &= ~KEY_POWER_BIT;
	}

	if(PushKey & KEY_MODE_BIT)
	{
		if(SystemStatus == eActive)
		{

			switch(SettingMode)
			{
			case eAll:
				SettingMode = eMode;
				break;
			case eMode:
				SettingMode = eFan;
				break;
			case eFan:
				SettingMode = eTemp;
				break;
			case eTemp:
				SettingMode = eTime;
				break;
			case eTime:
				SettingMode = e1224;
				break;
			case e1224:
				SettingMode = eTimer;
				Timer_disp = true;
				LCD_Display_Timer(TimerData);
				break;
			case eTimer:
				SettingMode = eCF;
				Timer_disp = false;
				LCD_Display_Time(tRTCData,Timeformat);
				break;
			case eCF:
				SettingMode = eSwing;
				break;
			case eSwing:
				SettingMode = eAll;
				break;
			}
			LCD_Display_SettingMode(SettingMode);
			KEY_PORT_IFG &= ~KEY_MODE_BIT;
		}
	}
	if(PushKey & KEY_UP_BIT)
	{
		if(SystemStatus == eActive)
		{
			switch(SettingMode)
			{
			case eAll:
				break;
			case eMode:
				TSMode++;
				if(TSMode > eFann)
					TSMode = eHeat;
				LCD_Display_TSMode(TSMode);
				break;
			case eFan:
				FanLevel++;
				if(FanLevel > eAuto)
					FanLevel = eL0;
				LCD_Display_Fan(FanLevel);
				break;
			case eTemp:
				SettingTemp++;
				if(SettingTemp > 32)
					SettingTemp = 32;
				LCD_Display_TempSet(SettingTemp,Tempformat);
				break;
			case eTime:
				tRTCData.MINUTE++;
				if (tRTCData.MINUTE > 59)
					tRTCData.MINUTE = 0;
				LCD_Display_Time(tRTCData,Timeformat);
				break;
			case e1224:
				Timeformat++;
				if(Timeformat > e24hour)
					Timeformat = e12hour;
				LCD_Display_Time(tRTCData,Timeformat);
				break;
			case eTimer:
				TimerData.MINUTE += 15;
				if(TimerData.MINUTE>=60)
				{
					TimerData.HOUR ++;
					TimerData.MINUTE -= 60;
				}
				if(TimerData.HOUR > 12)
					TimerData.HOUR = 0;
				LCD_Display_Timer(TimerData);
				break;
			case eCF:
				Tempformat++;
				if(Tempformat > eDegF)
					Tempformat = eDegC;
				LCD_Display_Temperature(Temperature,Tempformat);
				LCD_Display_TempSet(SettingTemp,Tempformat);
				break;
			case eSwing:
				SwingStatus++;
				if(SwingStatus > eSwingenable)
					SwingStatus = eSwingdisable;
				LCD_Display_Swing(SwingStatus);
				break;
			}
		}
		KEY_PORT_IFG &= ~KEY_UP_BIT;
	}

	if(PushKey & KEY_DOWN_BIT)
	{
		if(SystemStatus == eActive)
		{
			switch(SettingMode)
			{
			case eAll:
				break;
			case eMode:
				switch(TSMode)
				{
				case eHeat:
					TSMode = eFann;
					break;
				case eFann:
					TSMode = eHumi;
					break;
				case eHumi:
					TSMode = eCool;
					break;
				case eCool:
					TSMode = eHeat;
					break;
				}
				LCD_Display_TSMode(TSMode);
				break;
			case eFan:
				switch(FanLevel)
				{
				case eAuto:
					FanLevel = eL4;
					break;
				case eL4:
					FanLevel = eL3;
					break;
				case eL3:
					FanLevel = eL2;
					break;
				case eL2:
					FanLevel = eL1;
					break;
				case eL1:
					FanLevel = eL0;
					break;
				case eL0:
					FanLevel = eAuto;
					break;
				}
				LCD_Display_Fan(FanLevel);
				break;
			case eTemp:
				SettingTemp--;
				if(SettingTemp < 16)
					SettingTemp = 16;
				LCD_Display_TempSet(SettingTemp,Tempformat);
				break;
			case eTime:
				tRTCData.HOUR++;
				if (tRTCData.HOUR > 23)
					tRTCData.HOUR = 0;
				LCD_Display_Time(tRTCData,Timeformat);
				break;
			case e1224:
				switch(tRTCData.Weekday)
				{
				case eSunday:
					tRTCData.Weekday = eMonday;
					break;
				case eMonday:
					tRTCData.Weekday = eTuesday;
					break;
				case eTuesday:
					tRTCData.Weekday = eWednesday;
					break;
				case eWednesday:
					tRTCData.Weekday = eThursday;
					break;
				case eThursday:
					tRTCData.Weekday = eFriday;
					break;
				case eFriday:
					tRTCData.Weekday = eSaturday;
					break;
				case eSaturday:
					tRTCData.Weekday = eSunday;
					break;
				}
				LCD_Display_Time(tRTCData,Timeformat);
				break;
			case eTimer:
				TimerData.MINUTE -= 15;
				if(TimerData.MINUTE < 0)
				{
					TimerData.HOUR --;
					TimerData.MINUTE += 60;
				}
				if(TimerData.HOUR < 0)
				{
					TimerData.HOUR = 0;
					TimerData.MINUTE = 0;
				}
				LCD_Display_Timer(TimerData);
				break;
			case eCF:
				switch(Tempformat)
				{
				case eDegC:
					Tempformat = eDegF;
					break;
				case eDegF:
					Tempformat = eDegC;
					break;
				}
				LCD_Display_Temperature(Temperature,Tempformat);
				LCD_Display_TempSet(SettingTemp,Tempformat);
				break;
			case eSwing:
				switch(SwingStatus)
				{
				case eSwingenable:
					SwingStatus = eSwingdisable;
					break;
				case eSwingdisable:
					SwingStatus = eSwingenable;
					break;
				}
				LCD_Display_Swing(SwingStatus);
				break;
			}
		}
		KEY_PORT_IFG &= ~KEY_DOWN_BIT;
	}
}

//Bat_Vol = (uint32_t)150 * 1023 / (ADCMEM0&0x3FF); //100
//ADC_done_flag = true;
//if(Bat_Vol < 280)
//{
//	// Battery low action. To do ...
//}
