//*****************************************************************************
//! msp_ts430fr4_comm.c
//
//! Functions to support RS485 communication.
//!
//!
//
//! \author Texas Instruments
//! \author A0222632
//
//! \version Release 1
//
//*****************************************************************************

#include <msp_ts430fr4_golbal.h>

#define TXBUF_SIZE 30
uint8_t ui8TX_buffer[TXBUF_SIZE];
uint8_t ui8TX_counter;
uint8_t ui8TX_number = TXBUF_SIZE;
#define RXBUF_SIZE 30
uint8_t ui8RX_buffer[RXBUF_SIZE];
uint8_t ui8RX_counter;
bool bRX_enable;
bool bRX_finished;

//*****************************************************************************
//
//! Perform eUSCI initialize.
//!
//
//! \no param
//!
//! \return None.
//
//*****************************************************************************
void eUSCIA0_Config()
{
	UART_PORT_SEL |= UART_BIT_TXD + UART_BIT_RXD; // set pin as UART function

	UCA0CTLW0 |= UCSWRST;                         // Put eUSCI in reset
	UCA0CTLW0 |= UCSSEL__SMCLK;   // 8-e-1 LSB SMCLK

	UCA0BR0 = 6;                                  // 9600 baud
	UCA0BR1 = 0;
	UCA0MCTLW = 0x2200 + UCOS16 + UCBRF_13;       // 1.04MHz/9600

	UCA0CTLW0 &= ~UCSWRST;                        // Initialize eUSCI
	UCA0IE |= UCRXIE;
}

//*****************************************************************************
//
//! Perform Send a frame.
//!
//
//! \param Ptr Length
//!
//! \return S or F .
//
//*****************************************************************************
uint8_t Uart_SendFrame(uint8_t *pPtr, uint8_t ui8Length)
{
	uint8_t ui8counter;
	if(UCA0IE & UCTXIE) return 0;                // Last frame hasn't been sent out
	if(ui8Length > TXBUF_SIZE) return 0;            // Length overflow the buffer
	for(ui8counter=0;ui8counter<ui8Length;ui8counter++)      // Load the data to buffer
	{
		ui8TX_buffer[ui8counter] = pPtr[ui8counter];
	}
	ui8TX_counter = 0;                               // Clear transfer counter
	ui8TX_number = ui8Length;                           // Number of bytes to be sent
	UCA0IFG |= UCTXIFG;                           // Set an interruput manually
	UCA0IE |= UCTXIE;                             // Enable transfer interrupt
	return 1;                                     // Send successfully
}

void HAL_RS485_INIT()
{
	eUSCIA0_Config();
}

tPacket tDataget;
uint8_t *pDataget = &tDataget.ui8SOF;
uint8_t Uart_DataProcess()
{
	uint8_t ui8counter = 0;
	uint8_t ui8temp = 0;
	tDataget.ui8SOF = ui8RX_buffer[ui8counter++];
	for(ui8temp = 0; ui8temp < 11; ui8temp++)
	{
		tDataget.Data[ui8temp] = ui8RX_buffer[ui8counter++];
	}
	tDataget.ui8EOF = ui8RX_buffer[ui8counter++];

	switch(tDataget.Data[0])
	{
	case 0xDD:
	{
		SystemStatus = eActive;
		SettingMode = eAll;
		Power_led_counter = 5;
		TimerData.HOUR = 1;
		TimerData.MINUTE = 0;
		TimerData.SECOND = 0;
		PWLED_ON();
		ADC_ON();
		LCD_Display_ON();
		LCD_Display_Time(tRTCData,Timeformat);
		LCD_Display_Temperature(Temperature,Tempformat);
		LCD_Display_BatteryVol(BatteryVol);
		LCD_Display_TempSet(SettingTemp,Tempformat);
		LCD_Display_Fan(FanLevel);
		LCD_Display_TSMode(TSMode);
		LCD_Display_SettingMode(SettingMode);
	}
	break;
	case 0x77:
	{
		SystemStatus = eStandby;
		PWLED_OFF();
		LCD_Display_OFF();
		ADC_OFF();
		GLED_OFF();
		RLED_OFF();
	}
	break;
	case 0x55:
		LCD_Display_Signal(true);
		RS485_Send_Flag = 1;
		break;
	case 0xAA:
	{
		LCD_Display_Signal(false);
		RS485_Send_Flag = 0;
	}
	break;
	}
	return (1);
}

void Send_Data()
{
	tDataget.Data[0] = (Temperature&0xFF00)>>8;
	tDataget.Data[1] = Temperature&0x00FF;
	Uart_SendFrame(pDataget,13);
}


#pragma vector=USCI_A0_VECTOR
__interrupt void USCI_A0_ISR(void)
{
	switch(__even_in_range(UCA0IV,USCI_UART_UCTXCPTIFG))
	{
	case USCI_NONE: break;
	case USCI_UART_UCRXIFG:
	{
		uint8_t ui8RX_temp;
		ui8RX_temp = UCA0RXBUF;
		if(!bRX_finished)
		{
			if(bRX_enable)
			{
				ui8RX_buffer[ui8RX_counter] = ui8RX_temp;
				if((ui8RX_temp == 0xAA) && (ui8RX_counter == 12))
				{
					bRX_enable = false;
					bRX_finished = true;
				}
				else ui8RX_counter++;
			}
			else if(ui8RX_temp == 0x55)
			{
				bRX_enable = true;
				ui8RX_counter = 0;
				ui8RX_buffer[ui8RX_counter++] = ui8RX_temp;
			}
		}
	}
		break;
	case USCI_UART_UCTXIFG:
		UCA0TXBUF = ui8TX_buffer[ui8TX_counter];
		ui8TX_counter++;
		if(ui8TX_counter>=ui8TX_number)
		{
			UCA0IE &= ~UCTXIE;
		}
		break;
	case USCI_UART_UCSTTIFG: break;
	case USCI_UART_UCTXCPTIFG: break;
	}
}
